==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/core/v1/EnvFromSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** EnvFromSource represents the source of a set of ConfigMaps */
final case class EnvFromSource(
  configMapRef : Option[io.k8s.api.core.v1.ConfigMapEnvSource] = None,
  prefix : Option[String] = None,
  secretRef : Option[io.k8s.api.core.v1.SecretEnvSource] = None
) {

  /** Returns a new data with configMapRef set to new value */
  def withConfigMapRef(value: io.k8s.api.core.v1.ConfigMapEnvSource) : EnvFromSource = copy(configMapRef = Some(value))
  /** if configMapRef has a value, transforms to the result of function*/
  def mapConfigMapRef(f: io.k8s.api.core.v1.ConfigMapEnvSource => io.k8s.api.core.v1.ConfigMapEnvSource) : EnvFromSource = copy(configMapRef = configMapRef.map(f))

  /** Returns a new data with prefix set to new value */
  def withPrefix(value: String) : EnvFromSource = copy(prefix = Some(value))
  /** if prefix has a value, transforms to the result of function*/
  def mapPrefix(f: String => String) : EnvFromSource = copy(prefix = prefix.map(f))

  /** Returns a new data with secretRef set to new value */
  def withSecretRef(value: io.k8s.api.core.v1.SecretEnvSource) : EnvFromSource = copy(secretRef = Some(value))
  /** if secretRef has a value, transforms to the result of function*/
  def mapSecretRef(f: io.k8s.api.core.v1.SecretEnvSource => io.k8s.api.core.v1.SecretEnvSource) : EnvFromSource = copy(secretRef = secretRef.map(f))
}

object EnvFromSource {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.EnvFromSource, T] = new Encoder[io.k8s.api.core.v1.EnvFromSource, T] {
        def apply(o: io.k8s.api.core.v1.EnvFromSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("configMapRef", o.configMapRef)
            .write("prefix", o.prefix)
            .write("secretRef", o.secretRef)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, EnvFromSource] = new Decoder[T, EnvFromSource] {
      def apply(t: T): Either[String, EnvFromSource] = for {
          obj <- ObjectReader(t)
          configMapRef <- obj.readOpt[io.k8s.api.core.v1.ConfigMapEnvSource]("configMapRef")
          prefix <- obj.readOpt[String]("prefix")
          secretRef <- obj.readOpt[io.k8s.api.core.v1.SecretEnvSource]("secretRef")
      } yield EnvFromSource (
          configMapRef = configMapRef,
          prefix = prefix,
          secretRef = secretRef
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.5.1-sources.jar: io/k8s/api/core/v1/EnvFromSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** EnvFromSource represents the source of a set of ConfigMaps */
final case class EnvFromSource(
  configMapRef : Option[io.k8s.api.core.v1.ConfigMapEnvSource] = None,
  prefix : Option[String] = None,
  secretRef : Option[io.k8s.api.core.v1.SecretEnvSource] = None
) {

  /** Returns a new data with configMapRef set to new value */
  def withConfigMapRef(value: io.k8s.api.core.v1.ConfigMapEnvSource) : EnvFromSource = copy(configMapRef = Some(value))
  /** if configMapRef has a value, transforms to the result of function*/
  def mapConfigMapRef(f: io.k8s.api.core.v1.ConfigMapEnvSource => io.k8s.api.core.v1.ConfigMapEnvSource) : EnvFromSource = copy(configMapRef = configMapRef.map(f))

  /** Returns a new data with prefix set to new value */
  def withPrefix(value: String) : EnvFromSource = copy(prefix = Some(value))
  /** if prefix has a value, transforms to the result of function*/
  def mapPrefix(f: String => String) : EnvFromSource = copy(prefix = prefix.map(f))

  /** Returns a new data with secretRef set to new value */
  def withSecretRef(value: io.k8s.api.core.v1.SecretEnvSource) : EnvFromSource = copy(secretRef = Some(value))
  /** if secretRef has a value, transforms to the result of function*/
  def mapSecretRef(f: io.k8s.api.core.v1.SecretEnvSource => io.k8s.api.core.v1.SecretEnvSource) : EnvFromSource = copy(secretRef = secretRef.map(f))
}

object EnvFromSource {

    implicit val encoder : Encoder[io.k8s.api.core.v1.EnvFromSource] = new Encoder[io.k8s.api.core.v1.EnvFromSource] {
        def apply[T : Builder](o: io.k8s.api.core.v1.EnvFromSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("configMapRef", o.configMapRef)
            .write("prefix", o.prefix)
            .write("secretRef", o.secretRef)
            .build
        }
    }

    implicit val decoder: Decoder[EnvFromSource] = new Decoder[EnvFromSource] {
      def apply[T : Reader](t: T): Either[String, EnvFromSource] = for {
          obj <- ObjectReader(t)
          configMapRef <- obj.readOpt[io.k8s.api.core.v1.ConfigMapEnvSource]("configMapRef")
          prefix <- obj.readOpt[String]("prefix")
          secretRef <- obj.readOpt[io.k8s.api.core.v1.SecretEnvSource]("secretRef")
      } yield EnvFromSource (
          configMapRef = configMapRef,
          prefix = prefix,
          secretRef = secretRef
        )
    }
}
